@@ -1,6 +1,6 @@
 #' Empty Bands Discovery
 #'
-#' Identifies unused codes across multiple S-matricies. Unused bands can be used to reduce the codebook as in Stammers (2011).
+#' Identifies unused codes across multiple S-matrices. Unused bands can be used to reduce the codebook as in Stammers (2011).
 #' 
 #' @param ... Two or more TDSC objects
 #' @keywords TDSC
@@ -20,6 +20,9 @@ emptyBands <- function(...) {
   x <- c()
   y <- c()
   for (i in 1:length(input)) {
+    if (typeof(input[[i]]) != "S4" | class(input[[i]]) != "tdsc") {
+      stop("Inputs to emptyBands must be TDSC objects.")
+    }
     s_matrix <- input[[i]]@s_matrix
     x <- c(x, rep(i, length(s_matrix)))
     y <- c(y, as.numeric(rownames(s_matrix)))
